(this.webpackJsonpstreamlit_card_select=this.webpackJsonpstreamlit_card_select||[]).push([[0],{60:function(e,t,a){e.exports=a(74)},74:function(e,t,a){"use strict";a.r(t);var r=a(5),n=a.n(r),i=a(52),o=a.n(i),c=a(0),l=a(1),s=a(2),p=a(3),m=a(44),u=a(56),g=a(97),d=a(31),h=a(98),v=a(94),b=a(93),f=a(99),E=a(100),y=a(96),k=["data"],x=function(e){var t,a=e.data,r=Object(d.a)(e,k),i=r.imgHeight||140;return t=r.active?Object(u.a)(r.theme,{palette:{background:{paper:r.theme.palette.primary.dark}}}):r.theme,n.a.createElement(h.a,{theme:t},n.a.createElement(v.a,{sx:{maxWidth:r.maxWidth},onClick:function(){return r.onClick(a.option)},elevation:r.active?8:3},n.a.createElement(b.a,null,a.image?n.a.createElement(f.a,{component:"img",image:a.image,alt:"image",height:i}):null,n.a.createElement(E.a,null,a.title?n.a.createElement(y.a,{gutterBottom:!0,variant:"h5",component:"div"},a.title):null,a.description?n.a.createElement(y.a,{variant:"body2",color:"textSecondary"},a.description):null))))},j=function(e){Object(s.a)(a,e);var t=Object(p.a)(a);function a(){var e;Object(l.a)(this,a);for(var r=arguments.length,i=new Array(r),o=0;o<r;o++)i[o]=arguments[o];return(e=t.call.apply(t,[this].concat(i))).state={active:null},e.render=function(){var t,a=Object(u.a)({palette:{mode:"light"===(null===(t=e.props.theme)||void 0===t?void 0:t.base)?"light":"dark",primary:{main:e.props.theme.primaryColor},text:{primary:e.props.theme.textColor}}});null===e.state.active&&void 0!==e.props.args.default&&e.setState({active:e.props.args.default});var r=e.props.args.options,i=e.props.args.spacing||2,o=e.props.args.xs||12,c=e.props.args.sm||6,l=e.props.args.md||4,s=e.props.args.lg||3,p=e.props.args.imgHeight||140;return n.a.createElement(g.a,{container:!0,spacing:i},r.map((function(t){return n.a.createElement(g.a,{item:!0,xs:o,sm:c,md:l,lg:s,key:t.option},n.a.createElement(x,{data:t,onClick:e.setCard,active:e.state.active===t.option,imgHeight:p,theme:a}))})))},e.setCard=function(t){e.setState({active:t},(function(){return m.a.setComponentValue(t)}))},e}return Object(c.a)(a)}(m.b),C=Object(m.c)(j);o.a.render(n.a.createElement(n.a.StrictMode,null,n.a.createElement(C,null)),document.getElementById("root"))}},[[60,1,2]]]);
//# sourceMappingURL=main.ffe65e8d.chunk.js.map