from streamlit_card_select.__version__ import __version__
from streamlit_card_select.component import card_select


if __name__ == '__main__':
    from streamlit_card_select.sample_app import app
    app()
